#[non_exhaustive]pub enum RegistrationError {
TypeConflict {
name: String,
existing: String,
requested: String,
},
NameConflict {
name: String,
existing: String,
requested: String,
},
LayoutConflict {
name: String,
detail: String,
},
InvalidTag {
name: String,
detail: String,
},
UnsupportedStorage {
name: String,
detail: String,
},
}Expand description
Component registration conflict or policy violation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TypeConflict
The same TypeId was registered with incompatible metadata.
Fields
NameConflict
The registration name is already bound to different metadata.
Fields
LayoutConflict
Size, alignment, or owner metadata does not match an existing entry.
Fields
InvalidTag
Typed tag registration violated zero-sized non-dropping requirements.
Fields
UnsupportedStorage
Requested storage policy is incompatible with the component shape.