BuildError

Enum BuildError 

#[non_exhaustive]
pub enum BuildError {
Show 26 variants PendingCommands, WorldRunning, WorldMutationPoisoned, LeaseMismatch, LiveLeaseAlreadyAttached, UnknownStage { label: String, }, UnknownSystem { label: String, }, UnknownSystemSet { label: String, }, DuplicateSystemSet { label: String, }, DuplicateSystemLabel { label: String, }, SystemInitialization { system: String, detail: String, }, CrossOperationEdge { from: String, to: String, }, CrossStageSystemEdge { from: String, to: String, }, MissingRequiredResource { name: String, }, UnregisteredEventRole { system: String, event: String, }, EventOperationMismatch { system: String, event: String, event_operation: StageOperation, system_operation: StageOperation, }, MissingEventProducer { system: String, event: String, }, UnreachableEventProducer { producer: String, consumer: String, event: String, }, SelfEdge { label: String, }, Cycle { path: Vec<String>, }, FixedUpdateWithoutConfig, FixedConfigWithoutFixedUpdate, StageOperationMismatch { label: String, }, InvalidStageFlushMode { label: String, mode: FlushMode, }, InvalidSystemFlushMode { label: String, mode: FlushMode, }, WorldBuild(WorldError),
}
Schedule construction failure before first execution.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PendingCommands

World still has unflushed deferred commands.



WorldRunning

World run guard is active; build requires an idle world.



WorldMutationPoisoned

Change-tick exhaustion poisoned the world.



LeaseMismatch

Attached execution lease does not match this schedule.



LiveLeaseAlreadyAttached

Another compiled schedule already holds a live world lease.



UnknownStage

Referenced stage label was never registered.

Fields

label: String


UnknownSystem

Ordering edge names a system that was never added.

Fields

label: String


UnknownSystemSet

System or ordering edge names an unregistered set.

Fields

label: String


DuplicateSystemSet

Same system-set label registered twice.

Fields

label: String


DuplicateSystemLabel

Two systems share the same label.

Fields

label: String


SystemInitialization

Build-time initializer for a system returned an error.

Fields

system: String
detail: String


CrossOperationEdge

Ordering edge would cross Update/Render operations.

Fields

from: String


CrossStageSystemEdge

System ordering edge spans different stages.

Fields

from: String


MissingRequiredResource

System declared a resource lock for a type not present in the world.

Fields

name: String


UnregisteredEventRole

System event role references an unregistered event or lifecycle channel.

Fields

system: String
event: String


EventOperationMismatch

Frame-retained event operation does not match the system’s stage operation.

Fields

system: String
event: String
event_operation: StageOperation
system_operation: StageOperation


MissingEventProducer

Internal frame event consumer has no emitting producer.

Fields

system: String
event: String


UnreachableEventProducer

Producer is not ordered before the consumer for the same frame event.

Fields

producer: String
consumer: String
event: String


SelfEdge

System depends on itself in the ordering graph.

Fields

label: String


Cycle

Stage-local ordering graph contains a cycle.

Fields

path: Vec<String>


FixedUpdateWithoutConfig

FixedUpdate systems exist but no fixed timestep was configured.



FixedConfigWithoutFixedUpdate

Fixed timestep configured without a FixedUpdate stage.



StageOperationMismatch

Re-adding a stage label with a different operation.

Fields

label: String


InvalidStageFlushMode

Flush mode is invalid for the stage’s operation.

Fields

label: String


InvalidSystemFlushMode

Flush mode is invalid for the system’s stage operation.

Fields

label: String


WorldBuild(WorldError)

Underlying world construction or attachment failed.