#[non_exhaustive]pub enum ChunkBuffersError {
LengthMismatch {
buffer_index: usize,
expected: usize,
actual: usize,
},
}Expand description
Failure to partition a fixed set of mutable buffers into matching chunks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LengthMismatch
A buffer does not have the same element count as the first buffer.