pub struct QueryCursor { /* private fields */ }Expand description
Last-observed change tick for one owner-bound added/changed query window.
Implementations
Sourceimpl QueryCursor
impl QueryCursor
Sourcepub fn from_spec_start<T: 'static>(
world: &mut World,
spec: &QuerySpec,
) -> Result<Self, QueryError>
pub fn from_spec_start<T: 'static>( world: &mut World, spec: &QuerySpec, ) -> Result<Self, QueryError>
Opens a window from the start of change history for a single-component query.
Sourcepub fn from_spec_now<T: 'static>(
world: &mut World,
spec: &QuerySpec,
) -> Result<Self, QueryError>
pub fn from_spec_now<T: 'static>( world: &mut World, spec: &QuerySpec, ) -> Result<Self, QueryError>
Opens a window ending at the world’s current change tick for a single-component query.
Sourcepub fn from_spec2_start<A: 'static, B: 'static>(
world: &mut World,
spec: &QuerySpec,
) -> Result<Self, QueryError>
pub fn from_spec2_start<A: 'static, B: 'static>( world: &mut World, spec: &QuerySpec, ) -> Result<Self, QueryError>
Opens a window from the start of change history for a two-component query.
Sourcepub fn from_spec2_now<A: 'static, B: 'static>(
world: &mut World,
spec: &QuerySpec,
) -> Result<Self, QueryError>
pub fn from_spec2_now<A: 'static, B: 'static>( world: &mut World, spec: &QuerySpec, ) -> Result<Self, QueryError>
Opens a window ending at the world’s current change tick for a two-component query.
Sourcepub fn since(&self) -> ChangeTick
pub fn since(&self) -> ChangeTick
Lower bound of the active half-open change window (since, captured_now].