#[non_exhaustive]pub enum ScheduleError {
OwnerMismatch,
StaleHandle,
DuplicateStageInPlan,
NonUpdateStageInPlan,
StartupStageInPlan,
SystemNotFound {
label: String,
},
}Expand description
Runtime schedule control failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OwnerMismatch
Handle was issued by a different schedule instance.
StaleHandle
Handle index or generation no longer matches the compiled schedule.
DuplicateStageInPlan
Update plan lists the same stage more than once.
NonUpdateStageInPlan
Update plan includes a Render-only stage.
StartupStageInPlan
Startup is implicit on first update and cannot be planned explicitly.
SystemNotFound
No compiled system matches the label.