SystemInitContext

Struct SystemInitContext 

pub struct SystemInitContext<'world> { /* private fields */ }
Restricted build-time access used to create persistent system-local state.

Initializers may inspect resources and create event readers, but cannot mutate the world. The context is constructed only while a schedule builds.

Implementations

Source

impl<'world> SystemInitContext<'world>

pub fn contains_resource<R: 'static>(&self) -> bool

Whether the resource type is registered and present.

pub fn resource<R: 'static>(&self) -> Result<Option<&R>, WorldError>

Read-only resource access during initializer execution.

pub fn event_reader<E: Clone + 'static>( &mut self, start: EventReaderStart, ) -> Result<EventReader<E>, WorldError>

Persistent event reader seeded for the compiled system’s lifetime.

pub fn on_add_reader<T: 'static>( &mut self, start: EventReaderStart, ) -> Result<EventReader<ComponentAdded>, WorldError>

Persistent component-added lifecycle reader for this system.

pub fn on_remove_reader<T: 'static>( &mut self, start: EventReaderStart, ) -> Result<EventReader<ComponentRemoved>, WorldError>

Persistent component-removed lifecycle reader for this system.

pub fn prepare_query1<T: 'static>( &mut self, spec: QuerySpec, policy: QueryPolicy, ) -> Result<PreparedQuery1<T>, QueryError>

Resolves and stores a reusable single-component query for this system.

pub fn prepare_query2<A: 'static, B: 'static>( &mut self, spec: QuerySpec, policy: QueryPolicy, ) -> Result<PreparedQuery2<A, B>, QueryError>

Resolves and stores a reusable two-component query for this system.