AsyncExecutor

Struct AsyncExecutor 

pub struct AsyncExecutor { /* private fields */ }
Native async executor with access to the PAL I/O reactor.

Implementations

Source

impl AsyncExecutor

pub fn new() -> Result<AsyncExecutor, Error>

Create a new native async executor with a PAL I/O reactor handle.

pub fn spawn<F, T>(&self, future: F) -> AsyncHandle<T> ⓘ
where F: Future<Output = T> + Send + 'static, T: Send + 'static,

Spawn an async task with default priority.

pub fn spawn_with_priority<F, T>( &self, future: F, priority: Priority, ) -> AsyncHandle<T> ⓘ
where F: Future<Output = T> + Send + 'static, T: Send + 'static,

Spawn an async task with specified priority.

pub fn run(&self) -> Result<(), Error>

Run the native async executor and poll the PAL reactor between task passes.

pub fn stop(&self) -> Result<(), Error>

Stop the async executor.

pub fn stats(&self) -> ExecutorStats

Get current executor statistics.

pub fn block_on<F, T>(&self, future: F) -> T
where F: Future<Output = T> + Send + 'static, T: Send + 'static,

Block on a future, running the executor until it completes.

pub fn reactor(&self) -> &IoReactor

Get access to the underlying I/O reactor for advanced operations.