pub struct File { /* private fields */ }Expand description
Async file handle supporting stateful streams and positioned reads.
Implementations
Sourceimpl File
impl File
Sourcepub async fn open<P>(path: P) -> Result<File, Error>
pub async fn open<P>(path: P) -> Result<File, Error>
Open a file with default options (read-only)
Sourcepub async fn create<P>(path: P) -> Result<File, Error>
pub async fn create<P>(path: P) -> Result<File, Error>
Create a new file for writing (truncates if exists)
Sourcepub async fn open_with_options<P>(
path: P,
options: FileOpenOptions,
) -> Result<File, Error>
pub async fn open_with_options<P>( path: P, options: FileOpenOptions, ) -> Result<File, Error>
Open a file with custom options
Sourcepub async fn read_to_string(&mut self) -> Result<String, Error>
pub async fn read_to_string(&mut self) -> Result<String, Error>
Read entire file contents into a string
Sourcepub async fn read_to_end(&mut self) -> Result<Vec<u8>, Error>
pub async fn read_to_end(&mut self) -> Result<Vec<u8>, Error>
Read entire file contents into a byte vector
Sourcepub async fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
pub async fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Write all data from a buffer.
The whole buffer is one pool job: once submitted, it is written in full even if this future is dropped.
Sourcepub async fn sync_all(&mut self) -> Result<(), Error>
pub async fn sync_all(&mut self) -> Result<(), Error>
Synchronize all data and metadata to disk
Sourcepub async fn sync_data(&mut self) -> Result<(), Error>
pub async fn sync_data(&mut self) -> Result<(), Error>
Synchronize data (but not metadata) to disk
Sourcepub async fn seek(&mut self, pos: SeekFrom) -> Result<u64, Error>
pub async fn seek(&mut self, pos: SeekFrom) -> Result<u64, Error>
Seek to a specific position in the file
Sourcepub async fn stream_position(&mut self) -> Result<u64, Error>
pub async fn stream_position(&mut self) -> Result<u64, Error>
Get current position in the file