pub struct FixedStep {
pub index: u64,
pub delta: Duration,
pub steps: u64,
}Expand description
Fixed simulation substep identity while FixedUpdate runs.
Fields
index: u64Index of the first fixed interval represented by this run.
delta: DurationSimulation time represented by this run.
steps: u64Number of fixed intervals represented by this run.
This is one for ordinary fixed updates. A coalesced update represents more than one interval and advances the next index by this amount.