pub struct HybridConfig {
pub parallel_threshold: usize,
pub async_threshold: usize,
pub adaptation_factor: f64,
pub history_window: usize,
}Expand description
Configuration for hybrid execution strategy
Fields
parallel_threshold: usizeItem count below which the parallel strategy is selected.
async_threshold: usizeItem count above which the async strategy is selected.
adaptation_factor: f64Exponential weighting applied to new performance observations during adaptation.
history_window: usizeNumber of recent performance observations retained per strategy.