MoiraiIterator

Struct MoiraiIterator 

pub struct MoiraiIterator<T> { /* private fields */ }
Main iterator type that adapts to different execution contexts.

Implementations

Source

impl<T> MoiraiIterator<T>
where T: Send + 'static,

pub fn new(data: Vec<T>, context: ExecutionContext) -> MoiraiIterator<T>

Create a new iterator with the given execution context.

pub fn parallel(data: Vec<T>) -> MoiraiIterator<T>

Create with parallel context.

pub fn async_iter(data: Vec<T>) -> MoiraiIterator<T>

Create with async context.

pub fn hybrid(data: Vec<T>) -> MoiraiIterator<T>

Create with hybrid context.

pub fn map<F, R>(self, func: F) -> MoiraiIterator<R>
where F: Fn(T) -> R + Send + Sync + 'static, R: Send + 'static,

Map operation that preserves the execution context.

pub async fn map_async<F, Fut, R>(self, func: F) -> MoiraiIterator<R>
where F: Fn(T) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static, R: Send + 'static,

Async map operation for I/O-bound transformations.

pub fn filter<F>(self, predicate: F) -> MoiraiIterator<T>
where F: Fn(&T) -> bool + Send + Sync + 'static,

Filter operation.

pub async fn filter_async<F, Fut>(self, predicate: F) -> MoiraiIterator<T>
where F: Fn(&T) -> Fut + Send + Sync + 'static, Fut: Future<Output = bool> + Send + 'static,

Async filter operation.

pub async fn collect(self) -> Vec<T>

Collect the results.

pub async fn collect_async(self) -> Vec<T>

Async collect that waits for all tasks to complete.

pub async fn reduce<F>(self, func: F) -> Option<T>
where F: Fn(T, T) -> T + Send + Sync + 'static,

Reduce operation.

pub async fn reduce_parallel<F>(self, func: F) -> Option<T>
where F: Fn(T, T) -> T + Send + Sync + 'static,

Parallel reduce with work-stealing.

pub async fn for_each<F>(self, func: F)
where F: Fn(T) + Send + Sync + 'static,

For each operation with side effects.

pub async fn for_each_async<F, Fut>(self, func: F)
where F: Fn(T) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Async for each operation.

pub fn into_async_stream(self) -> impl Stream<Item = T> + Send + 'static
where T: 'static,

Convert to async stream for streaming processing.