pub trait ParallelExtend<T>: Send {
// Required method
fn par_extend<I>(&mut self, par_iter: I)
where I: ParallelIterator<Item = T>;
}Expand description
Trait for collections that can be extended in parallel.
Required Methods
Sourcefn par_extend<I>(&mut self, par_iter: I)where
I: ParallelIterator<Item = T>,
fn par_extend<I>(&mut self, par_iter: I)where
I: ParallelIterator<Item = T>,
Extend the collection with items from a parallel iterator.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".