#[non_exhaustive]pub enum EntityScratchError {
WrongWorld,
StaleEntity {
entity: EntityId,
},
EntityNotLive {
entity: EntityId,
},
}Expand description
Failure while accessing DenseEntityScratch against a bound world.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongWorld
The supplied world is not the world that created the scratch storage.
StaleEntity
The entity generation is no longer live in the bound world.
EntityNotLive
The entity belongs to the bound world but is not live yet.