pub struct SpscReceiver<T> { /* private fields */ }Expand description
Receiver half of SPSC channel.
The single-consumer half of the pair, !Sync for the same reason as
SpscSender — two shared receivers would assume_init_read one slot
twice, moving out of it and then dropping it twice.
Implementations
Sourceimpl<T> SpscReceiver<T>where
T: Send,
impl<T> SpscReceiver<T>where
T: Send,
Sourcepub fn recv(&self) -> Result<T, ChannelError>
pub fn recv(&self) -> Result<T, ChannelError>
Receive a value from the channel, blocking until one arrives.
Sourcepub fn try_recv(&self) -> Result<T, ChannelError>
pub fn try_recv(&self) -> Result<T, ChannelError>
Try to receive a value without blocking.