ExecutionContext

Enum ExecutionContext 

pub enum ExecutionContext {
    Parallel(ParallelContext),
    Async(AsyncContext),
    Hybrid(HybridContext),
}
Concrete execution context enum that wraps different strategy implementations This approach ensures type safety while avoiding dyn-compatibility issues

Variants



Parallel(ParallelContext)

Parallel execution for CPU-bound work



Async(AsyncContext)

Async execution for I/O-bound work



Hybrid(HybridContext)

Hybrid execution that adapts between strategies

Implementations

Source

impl ExecutionContext

pub fn execute<F, R>(&self, func: F) -> Result<R, Box<dyn Error + Send + Sync>>
where F: FnOnce() -> R + Send, R: Send,

Execute a function once with the appropriate context

pub fn execute_iter<T, F, R>( &self, items: Vec<T>, func: F, ) -> Result<Vec<R>, Box<dyn Error + Send + Sync>>
where T: Send + 'static, F: Fn(T) -> R + Send + Sync + 'static, R: Send + 'static,

Execute an iterator operation with proper type erasure

pub async fn execute_async_iter<T, F, Fut, R>( &self, items: Vec<T>, func: F, ) -> Result<Vec<R>, Box<dyn Error + Send + Sync>>
where T: Send + 'static, F: Fn(T) -> Fut + Send + Sync + 'static, Fut: Future<Output = R> + Send + 'static, R: Send + 'static,

Execute async iterator operations

pub async fn execute_async_filter<T, F, Fut>( &self, items: Vec<T>, predicate: F, ) -> Result<Vec<T>, Box<dyn Error + Send + Sync>>
where T: Send + 'static, F: Fn(&T) -> Fut + Send + Sync + 'static, Fut: Future<Output = bool> + Send + 'static,

Execute async filter operations

pub async fn execute_async_for_each<T, F, Fut>( &self, items: Vec<T>, func: F, ) -> Result<(), Box<dyn Error + Send + Sync>>
where T: Send + 'static, F: Fn(T) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Execute async for_each operations

pub async fn execute_reduce<T, F>( &self, items: Vec<T>, func: F, ) -> Result<Option<T>, Box<dyn Error + Send + Sync>>
where T: Send + 'static, F: Fn(T, T) -> T + Send + Sync + 'static,

Execute parallel reduce operations

pub fn context_type(&self) -> &'static str

Get context type name