pub struct AsyncExecutor { /* private fields */ }Expand description
Native async executor with access to the PAL I/O reactor.
Implementations
Sourceimpl AsyncExecutor
impl AsyncExecutor
Sourcepub fn new() -> Result<AsyncExecutor, Error>
pub fn new() -> Result<AsyncExecutor, Error>
Create a new native async executor with a PAL I/O reactor handle.
Sourcepub fn spawn<F, T>(&self, future: F) -> AsyncHandle<T> ⓘ
pub fn spawn<F, T>(&self, future: F) -> AsyncHandle<T> ⓘ
Spawn an async task with default priority.
Sourcepub fn spawn_with_priority<F, T>(
&self,
future: F,
priority: Priority,
) -> AsyncHandle<T> ⓘ
pub fn spawn_with_priority<F, T>( &self, future: F, priority: Priority, ) -> AsyncHandle<T> ⓘ
Spawn an async task with specified priority.
Sourcepub fn run(&self) -> Result<(), Error>
pub fn run(&self) -> Result<(), Error>
Run the native async executor and poll the PAL reactor between task passes.
Sourcepub fn stats(&self) -> ExecutorStats
pub fn stats(&self) -> ExecutorStats
Get current executor statistics.