pub trait ArchiveView: Send + 'static {
type Archived<'a>
where Self: 'a;
// Required method
fn view_archive(bytes: &[u8]) -> Result<Self::Archived<'_>, ChannelError>;
}Expand description
Validates archive bytes and returns a typed borrowed view.
Required Associated Types
Required Methods
Sourcefn view_archive(bytes: &[u8]) -> Result<Self::Archived<'_>, ChannelError>
fn view_archive(bytes: &[u8]) -> Result<Self::Archived<'_>, ChannelError>
Validate and view an archived value without allocating an owned value.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".